@@ -1,10 +1,15 @@
 assoc.twocat.by  <- function(x, y, by, weights = NULL, na.rm = FALSE, na.value = "NAs", nperm = NULL, distrib = "asympt") {
 
-  df <- data.frame(x,y)
+  if (is.null(weights)) 
+    weights <- rep(1, length(x))
+  if (any(is.na(weights))) 
+    stop("There are empty values in weights.")
+  
+  df <- data.frame(x, y, weights)
   spl <- split(df, by)
-  ass <- lapply(spl, function(z) with(z, assoc.twocat(x,y,weights = weights,
-                                                      na.rm=na.rm,na.value=na.value,
-                                                      nperm=nperm,distrib=distrib)))
+  ass <- lapply(spl, function(z) assoc.twocat(z$x, z$y, z$weights,
+                                              na.rm = na.rm, na.value = na.value,
+                                              nperm = nperm, distrib = distrib))
 
   res <- list()
   res$tables$freq <- lapply(ass, function(x) x$tables$freq)
